@@ -1,4 +1,4 @@
-# $Id: SQL.pm 40298 2013-09-25 10:00:59Z anton $
+# $Id: SQL.pm 40714 2013-12-11 12:07:05Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/SQL.pm $
 #
 # Er wordt door deze app geschreven naar adb123, die wordt eens in het uur ofzo gelezen
@@ -101,24 +101,6 @@ sub new {
 	$self->{setMail} = $db->prepare('INSERT INTO adb131@lnkdea.kub.nl (anr, extmail, epoch_time) VALUES (?,?,?)');
 	$self->{deleteMail} = $db->prepare('DELETE FROM adb131@lnkdea.kub.nl WHERE anr = ?');
 	$self->{setQAMTime} = $db->prepare('INSERT INTO adb131@lnkdea.kub.nl (anr, epochtime) VALUES (?,?)');
-	$self->{getExpiredAccounts} = $db->prepare("SELECT a.anr, a.vrvg, a.famnaam, 
-									                   b.epoch_time, b.account, b.mailname,
-									                   d.orgnaam 
-                                                FROM   deabeh.adb301 a,
-									                   deabeh.adv001userandmailnaam b, 
-                                                       deabeh.psb300 d
-								                WHERE  a.anr = b.anr
-                                                AND    a.anr = d.anr
-										        AND    d.orgnaam LIKE 'LIS:%'
-                                                AND    a.anr = '780251'
-                                                AND    b.epoch_time < ?
-                                                ORDER BY b.epoch_time" );
-
-	$self->{getTotalNumberOfAccounts} = $db->prepare("SELECT COUNT (anr) FROM deabeh.adv001userandmailnaam");
-	$self->{getExpirationStatus} = $db->prepare("SELECT anr, status, epoch_time FROM adb124\@lnkdea.kub.nl WHERE anr = ?");
-	$self->{clearExpirationStatus} = $db->prepare('DELETE FROM adb124@lnkdea.kub.nl WHERE anr = ?');
-	$self->{newExpirationStatus} = $db->prepare('INSERT into adb124@lnkdea.kub.nl (anr, epoch_time, status) VALUES (?,?,?)');
-	$self->{changeExpirationStatus} = $db->prepare('UPDATE adb124@lnkdea.kub.nl SET epoch_time=?, status=? WHERE anr = ?');
 	$self->{getLatestRcryptPassword} = $db->prepare('SELECT pw_rcrypt_after FROM adb123@lnkdea.kub.nl
 			          WHERE epoch_time = (SELECT MAX (epoch_time) FROM adb123@lnkdea.kub.nl WHERE anr=?)');
 
@@ -274,33 +256,6 @@ sub getCurrentSHAPassword {
 	return $a->[-1];
 }
 
-sub getExpiredAccounts {
-	my $timeDragline = shift;
-	warn "timeDragline: $timeDragline";
-	my $field = 'ANR';
-	my $res = $self->query_fetchall_hashref($field, 'getExpiredAccounts', $timeDragline);
-	warn "Res:";
-	warn Dumper($res);
-	return $res;
-}
-
-sub getExpirationStatus {
-	my $anr = shift;
-	my $res = $self->query_fetchall('getExpirationStatus', $anr);
- 	return  $res;
-}
-
-sub getExpirationStatusHash {
-	my $anr = shift;
-	my $res = $self->query_fetchrow_hashref('getExpirationStatus', $anr);
- 	return  $res;
-}
-
-sub getTotalNumberOfAccounts {
-	my $res = $self->query_fetch('getTotalNumberOfAccounts');
-	return $res;
-}
-
 sub previousPasswords {
 	my $anr = shift;
 	my $res = $self->query_fetchall('previousPasswords', $anr);
